Class: Aws::RoboMaker::Types::BatchPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::BatchPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Information about the batch policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_concurrency ⇒ Integer
The number of active simulation jobs create as part of the batch that can be in an active state at the same time.
-
#timeout_in_seconds ⇒ Integer
The amount of time, in seconds, to wait for the batch to complete.
Instance Attribute Details
#max_concurrency ⇒ Integer
The number of active simulation jobs create as part of the batch that can be in an active state at the same time.
Active states include: Pending,Preparing, Running, Restarting, RunningFailed and Terminating. All other states are terminal states.
93 94 95 96 97 98 |
# File 'lib/aws-sdk-robomaker/types.rb', line 93 class BatchPolicy < Struct.new( :timeout_in_seconds, :max_concurrency) SENSITIVE = [] include Aws::Structure end |
#timeout_in_seconds ⇒ Integer
The amount of time, in seconds, to wait for the batch to complete.
If a batch times out, and there are pending requests that were failing due to an internal failure (like InternalServiceError), they will be moved to the failed list and the batch status will be Failed. If the pending requests were failing for any other reason, the failed pending requests will be moved to the failed list and the batch status will be TimedOut.
93 94 95 96 97 98 |
# File 'lib/aws-sdk-robomaker/types.rb', line 93 class BatchPolicy < Struct.new( :timeout_in_seconds, :max_concurrency) SENSITIVE = [] include Aws::Structure end |