Class: Aws::RoboMaker::Types::CreateSimulationApplicationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-robomaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the simulation application.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#environmentTypes::Environment

The object that contains the Docker image URI that you used to create your simulation application.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The time, in milliseconds since the epoch, when the simulation application was last updated.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the simulation application.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#rendering_engineTypes::RenderingEngine

The rendering engine for the simulation application.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

The revision id of the simulation application.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#robot_software_suiteTypes::RobotSoftwareSuite

Information about the robot software suite.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#simulation_software_suiteTypes::SimulationSoftwareSuite

The simulation software suite used by the simulation application.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::Source>

The sources of the simulation application.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The list of all tags added to the simulation application.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the simulation application.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/aws-sdk-robomaker/types.rb', line 776

class CreateSimulationApplicationResponse < Struct.new(
  :arn,
  :name,
  :version,
  :sources,
  :simulation_software_suite,
  :robot_software_suite,
  :rendering_engine,
  :last_updated_at,
  :revision_id,
  :tags,
  :environment)
  SENSITIVE = []
  include Aws::Structure
end