Class: Aws::RoboMaker::Types::CreateWorldExportJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-robomaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the world export job.



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/aws-sdk-robomaker/types.rb', line 1276

class CreateWorldExportJobResponse < Struct.new(
  :arn,
  :status,
  :created_at,
  :failure_code,
  :client_request_token,
  :output_location,
  :iam_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_request_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/aws-sdk-robomaker/types.rb', line 1276

class CreateWorldExportJobResponse < Struct.new(
  :arn,
  :status,
  :created_at,
  :failure_code,
  :client_request_token,
  :output_location,
  :iam_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time, in milliseconds since the epoch, when the world export job was created.



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/aws-sdk-robomaker/types.rb', line 1276

class CreateWorldExportJobResponse < Struct.new(
  :arn,
  :status,
  :created_at,
  :failure_code,
  :client_request_token,
  :output_location,
  :iam_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_codeString

The failure code of the world export job if it failed:

InternalServiceError

: Internal service error.

LimitExceeded

: The requested resource exceeds the maximum number allowed, or the number of concurrent stream requests exceeds the maximum number allowed.

ResourceNotFound

: The specified resource could not be found.

RequestThrottled

: The request was throttled.

InvalidInput

: An input parameter in the request is not valid.

AllWorldGenerationFailed

: All of the worlds in the world generation job failed. This can happen if your worldCount is greater than 50 or less than 1.

For more information about troubleshooting WorldForge, see Troubleshooting Simulation WorldForge.



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/aws-sdk-robomaker/types.rb', line 1276

class CreateWorldExportJobResponse < Struct.new(
  :arn,
  :status,
  :created_at,
  :failure_code,
  :client_request_token,
  :output_location,
  :iam_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#iam_roleString

The IAM role that the world export process uses to access the Amazon S3 bucket and put the export.



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/aws-sdk-robomaker/types.rb', line 1276

class CreateWorldExportJobResponse < Struct.new(
  :arn,
  :status,
  :created_at,
  :failure_code,
  :client_request_token,
  :output_location,
  :iam_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_locationTypes::OutputLocation

The output location.



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/aws-sdk-robomaker/types.rb', line 1276

class CreateWorldExportJobResponse < Struct.new(
  :arn,
  :status,
  :created_at,
  :failure_code,
  :client_request_token,
  :output_location,
  :iam_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the world export job.

Pending

: The world export job request is pending.

Running

: The world export job is running.

Completed

: The world export job completed.

Failed

: The world export job failed. See failureCode for more information.

Canceled

: The world export job was cancelled.

Canceling

: The world export job is being cancelled.



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/aws-sdk-robomaker/types.rb', line 1276

class CreateWorldExportJobResponse < Struct.new(
  :arn,
  :status,
  :created_at,
  :failure_code,
  :client_request_token,
  :output_location,
  :iam_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A map that contains tag keys and tag values that are attached to the world export job.



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/aws-sdk-robomaker/types.rb', line 1276

class CreateWorldExportJobResponse < Struct.new(
  :arn,
  :status,
  :created_at,
  :failure_code,
  :client_request_token,
  :output_location,
  :iam_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end