Class: Aws::RoboMaker::Types::ListFleetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::ListFleetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Optional filters to limit results.
-
#max_results ⇒ Integer
When this parameter is used,
ListFleetsonly returnsmaxResultsresults in a single page along with anextTokenresponse element. -
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object's
nextTokenparameter value is set to a token.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Optional filters to limit results.
The filter name name is supported. When filtering, you must use
the complete value of the filtered item. You can use up to three
filters.
3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3313 class ListFleetsRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
When this parameter is used, ListFleets only returns maxResults
results in a single page along with a nextToken response element.
The remaining results of the initial request can be seen by sending
another ListFleets request with the returned nextToken value.
This value can be between 1 and 200. If this parameter is not used,
then ListFleets returns up to 200 results and a nextToken value
if applicable.
3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3313 class ListFleetsRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous paginated request did not return all of the
remaining results, the response object's nextToken parameter
value is set to a token. To retrieve the next set of results, call
ListFleets again and assign that token to the request object's
nextToken parameter. If there are no remaining results, the
previous response object's NextToken parameter is set to null.
3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3313 class ListFleetsRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |