Class: Aws::RoboMaker::Types::ListFleetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::ListFleetsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_details ⇒ Array<Types::Fleet>
A list of fleet details meeting the request criteria.
-
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s
nextTokenparameter value is set to a token.
Instance Attribute Details
#fleet_details ⇒ Array<Types::Fleet>
A list of fleet details meeting the request criteria.
3336 3337 3338 3339 3340 3341 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3336 class ListFleetsResponse < Struct.new( :fleet_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s nextToken parameter value is set to a token. To retrieve the next set of results, call ListFleets again and assign that token to the request object’s nextToken parameter. If there are no remaining results, the previous response object’s NextToken parameter is set to null.
3336 3337 3338 3339 3340 3341 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3336 class ListFleetsResponse < Struct.new( :fleet_details, :next_token) SENSITIVE = [] include Aws::Structure end |