Class: Aws::RoboMaker::Types::ListRobotApplicationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::ListRobotApplicationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s
nextTokenparameter value is set to a token. -
#robot_application_summaries ⇒ Array<Types::RobotApplicationSummary>
A list of robot application summaries that meet the criteria of the request.
Instance Attribute Details
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s nextToken parameter value is set to a token. To retrieve the next set of results, call ListRobotApplications again and assign that token to the request object’s nextToken parameter. If there are no remaining results, the previous response object’s NextToken parameter is set to null.
3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3401 class ListRobotApplicationsResponse < Struct.new( :robot_application_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#robot_application_summaries ⇒ Array<Types::RobotApplicationSummary>
A list of robot application summaries that meet the criteria of the request.
3401 3402 3403 3404 3405 3406 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3401 class ListRobotApplicationsResponse < Struct.new( :robot_application_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |