Class: Aws::RoboMaker::Types::ListRobotsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-robomaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the previous paginated request did not return all of the remaining results, the response object’s nextToken parameter value is set to a token. To retrieve the next set of results, call ListRobots again and assign that token to the request object’s nextToken parameter. If there are no remaining results, the previous response object’s NextToken parameter is set to null.

Returns:

  • (String)


3462
3463
3464
3465
3466
3467
# File 'lib/aws-sdk-robomaker/types.rb', line 3462

class ListRobotsResponse < Struct.new(
  :robots,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#robotsArray<Types::Robot>

A list of robots that meet the criteria of the request.

Returns:



3462
3463
3464
3465
3466
3467
# File 'lib/aws-sdk-robomaker/types.rb', line 3462

class ListRobotsResponse < Struct.new(
  :robots,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end