Class: Aws::RoboMaker::Types::ListSimulationApplicationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::ListSimulationApplicationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Optional list of filters to limit results.
-
#max_results ⇒ Integer
When this parameter is used,
ListSimulationApplicationsonly returnsmaxResultsresults in a single page along with anextTokenresponse element. -
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object's
nextTokenparameter value is set to a token. -
#version_qualifier ⇒ String
The version qualifier of the simulation application.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Optional list of filters to limit results.
The filter name name is supported. When filtering, you must use
the complete value of the filtered item. You can use up to three
filters.
3504 3505 3506 3507 3508 3509 3510 3511 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3504 class ListSimulationApplicationsRequest < Struct.new( :version_qualifier, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
When this parameter is used, ListSimulationApplications only
returns maxResults results in a single page along with a
nextToken response element. The remaining results of the initial
request can be seen by sending another ListSimulationApplications
request with the returned nextToken value. This value can be
between 1 and 100. If this parameter is not used, then
ListSimulationApplications returns up to 100 results and a
nextToken value if applicable.
3504 3505 3506 3507 3508 3509 3510 3511 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3504 class ListSimulationApplicationsRequest < Struct.new( :version_qualifier, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous paginated request did not return all of the
remaining results, the response object's nextToken parameter
value is set to a token. To retrieve the next set of results, call
ListSimulationApplications again and assign that token to the
request object's nextToken parameter. If there are no remaining
results, the previous response object's NextToken parameter is set
to null.
3504 3505 3506 3507 3508 3509 3510 3511 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3504 class ListSimulationApplicationsRequest < Struct.new( :version_qualifier, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#version_qualifier ⇒ String
The version qualifier of the simulation application.
3504 3505 3506 3507 3508 3509 3510 3511 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3504 class ListSimulationApplicationsRequest < Struct.new( :version_qualifier, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |