Class: Aws::RoboMaker::Types::ListSimulationApplicationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::ListSimulationApplicationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s
nextTokenparameter value is set to a token. -
#simulation_application_summaries ⇒ Array<Types::SimulationApplicationSummary>
A list of simulation application summaries that meet the criteria of the request.
Instance Attribute Details
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s nextToken parameter value is set to a token. To retrieve the next set of results, call ListSimulationApplications again and assign that token to the request object’s nextToken parameter. If there are no remaining results, the previous response object’s NextToken parameter is set to null.
3530 3531 3532 3533 3534 3535 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3530 class ListSimulationApplicationsResponse < Struct.new( :simulation_application_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#simulation_application_summaries ⇒ Array<Types::SimulationApplicationSummary>
A list of simulation application summaries that meet the criteria of the request.
3530 3531 3532 3533 3534 3535 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3530 class ListSimulationApplicationsResponse < Struct.new( :simulation_application_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |