Class: Aws::RoboMaker::Types::ListSimulationJobsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::ListSimulationJobsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s
nextTokenparameter value is set to a token. -
#simulation_job_summaries ⇒ Array<Types::SimulationJobSummary>
A list of simulation job summaries that meet the criteria of the request.
Instance Attribute Details
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s nextToken parameter value is set to a token. To retrieve the next set of results, call ListSimulationJobs again and assign that token to the request object’s nextToken parameter. If there are no remaining results, the previous response object’s NextToken parameter is set to null.
3648 3649 3650 3651 3652 3653 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3648 class ListSimulationJobsResponse < Struct.new( :simulation_job_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#simulation_job_summaries ⇒ Array<Types::SimulationJobSummary>
A list of simulation job summaries that meet the criteria of the request.
3648 3649 3650 3651 3652 3653 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3648 class ListSimulationJobsResponse < Struct.new( :simulation_job_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |