Method: Aws::RoboMaker::Types::RobotApplicationConfig#use_default_tools
- Defined in:
- lib/aws-sdk-robomaker/types.rb
#use_default_tools ⇒ Boolean
A Boolean indicating whether to use default robot application tools. The default tools are rviz, rqt, terminal and rosbag record. The default is False.
This API is no longer supported and will throw an error if used.
4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 |
# File 'lib/aws-sdk-robomaker/types.rb', line 4248 class RobotApplicationConfig < Struct.new( :application, :application_version, :launch_config, :upload_configurations, :use_default_upload_configurations, :tools, :use_default_tools) SENSITIVE = [] include Aws::Structure end |