Class: Aws::RoboMaker::Types::SimulationJobBatchSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::SimulationJobBatchSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Information about a simulation job batch.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the batch.
-
#created_at ⇒ Time
The time, in milliseconds since the epoch, when the simulation job batch was created.
-
#created_request_count ⇒ Integer
The number of created simulation job requests.
-
#failed_request_count ⇒ Integer
The number of failed simulation job requests.
-
#last_updated_at ⇒ Time
The time, in milliseconds since the epoch, when the simulation job batch was last updated.
-
#pending_request_count ⇒ Integer
The number of pending simulation job requests.
-
#status ⇒ String
The status of the simulation job batch.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the batch.
4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/aws-sdk-robomaker/types.rb', line 4732 class SimulationJobBatchSummary < Struct.new( :arn, :last_updated_at, :created_at, :status, :failed_request_count, :pending_request_count, :created_request_count) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time, in milliseconds since the epoch, when the simulation job batch was created.
4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/aws-sdk-robomaker/types.rb', line 4732 class SimulationJobBatchSummary < Struct.new( :arn, :last_updated_at, :created_at, :status, :failed_request_count, :pending_request_count, :created_request_count) SENSITIVE = [] include Aws::Structure end |
#created_request_count ⇒ Integer
The number of created simulation job requests.
4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/aws-sdk-robomaker/types.rb', line 4732 class SimulationJobBatchSummary < Struct.new( :arn, :last_updated_at, :created_at, :status, :failed_request_count, :pending_request_count, :created_request_count) SENSITIVE = [] include Aws::Structure end |
#failed_request_count ⇒ Integer
The number of failed simulation job requests.
4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/aws-sdk-robomaker/types.rb', line 4732 class SimulationJobBatchSummary < Struct.new( :arn, :last_updated_at, :created_at, :status, :failed_request_count, :pending_request_count, :created_request_count) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time, in milliseconds since the epoch, when the simulation job batch was last updated.
4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/aws-sdk-robomaker/types.rb', line 4732 class SimulationJobBatchSummary < Struct.new( :arn, :last_updated_at, :created_at, :status, :failed_request_count, :pending_request_count, :created_request_count) SENSITIVE = [] include Aws::Structure end |
#pending_request_count ⇒ Integer
The number of pending simulation job requests.
4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/aws-sdk-robomaker/types.rb', line 4732 class SimulationJobBatchSummary < Struct.new( :arn, :last_updated_at, :created_at, :status, :failed_request_count, :pending_request_count, :created_request_count) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the simulation job batch.
Pending
: The simulation job batch request is pending.
InProgress
: The simulation job batch is in progress.
Failed
: The simulation job batch failed. One or more simulation job
requests could not be completed due to an internal failure (like
InternalServiceError). See failureCode and failureReason for
more information.
Completed
: The simulation batch job completed. A batch is complete when (1)
there are no pending simulation job requests in the batch and none
of the failed simulation job requests are due to
InternalServiceError and (2) when all created simulation jobs
have reached a terminal state (for example, Completed or
Failed).
Canceled
: The simulation batch job was cancelled.
Canceling
: The simulation batch job is being cancelled.
Completing
: The simulation batch job is completing.
TimingOut
: The simulation job batch is timing out.
If a batch timing out, and there are pending requests that were
failing due to an internal failure (like `InternalServiceError`),
the batch status will be `Failed`. If there are no such failing
request, the batch status will be `TimedOut`.
TimedOut
: The simulation batch job timed out.
4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/aws-sdk-robomaker/types.rb', line 4732 class SimulationJobBatchSummary < Struct.new( :arn, :last_updated_at, :created_at, :status, :failed_request_count, :pending_request_count, :created_request_count) SENSITIVE = [] include Aws::Structure end |