Class: Aws::RoboMaker::Types::Tool
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::Tool
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Information about a tool. Tools are used in a simulation job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command ⇒ String
Command-line arguments for the tool.
-
#exit_behavior ⇒ String
Exit behavior determines what happens when your tool quits running.
-
#name ⇒ String
The name of the tool.
-
#stream_output_to_cloud_watch ⇒ Boolean
Boolean indicating whether logs will be recorded in CloudWatch for the tool.
-
#stream_ui ⇒ Boolean
Boolean indicating whether a streaming session will be configured for the tool.
Instance Attribute Details
#command ⇒ String
Command-line arguments for the tool. It must include the tool executable name.
5366 5367 5368 5369 5370 5371 5372 5373 5374 |
# File 'lib/aws-sdk-robomaker/types.rb', line 5366 class Tool < Struct.new( :stream_ui, :name, :command, :stream_output_to_cloud_watch, :exit_behavior) SENSITIVE = [] include Aws::Structure end |
#exit_behavior ⇒ String
Exit behavior determines what happens when your tool quits running. RESTART will cause your tool to be restarted. FAIL will cause your job to exit. The default is RESTART.
5366 5367 5368 5369 5370 5371 5372 5373 5374 |
# File 'lib/aws-sdk-robomaker/types.rb', line 5366 class Tool < Struct.new( :stream_ui, :name, :command, :stream_output_to_cloud_watch, :exit_behavior) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the tool.
5366 5367 5368 5369 5370 5371 5372 5373 5374 |
# File 'lib/aws-sdk-robomaker/types.rb', line 5366 class Tool < Struct.new( :stream_ui, :name, :command, :stream_output_to_cloud_watch, :exit_behavior) SENSITIVE = [] include Aws::Structure end |
#stream_output_to_cloud_watch ⇒ Boolean
Boolean indicating whether logs will be recorded in CloudWatch for the tool. The default is False.
5366 5367 5368 5369 5370 5371 5372 5373 5374 |
# File 'lib/aws-sdk-robomaker/types.rb', line 5366 class Tool < Struct.new( :stream_ui, :name, :command, :stream_output_to_cloud_watch, :exit_behavior) SENSITIVE = [] include Aws::Structure end |
#stream_ui ⇒ Boolean
Boolean indicating whether a streaming session will be configured for the tool. If True, AWS RoboMaker will configure a connection so you can interact with the tool as it is running in the simulation. It must have a graphical user interface. The default is False.
5366 5367 5368 5369 5370 5371 5372 5373 5374 |
# File 'lib/aws-sdk-robomaker/types.rb', line 5366 class Tool < Struct.new( :stream_ui, :name, :command, :stream_output_to_cloud_watch, :exit_behavior) SENSITIVE = [] include Aws::Structure end |