Class: Aws::RoboMaker::Types::ListDeploymentJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::ListDeploymentJobsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Optional filters to limit results.
-
#max_results ⇒ Integer
When this parameter is used,
ListDeploymentJobsonly returnsmaxResultsresults in a single page along with anextTokenresponse element. -
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s
nextTokenparameter value is set to a token.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Optional filters to limit results.
The filter names status and fleetName are supported. When filtering, you must use the complete value of the filtered item. You can use up to three filters, but they must be for the same named item. For example, if you are looking for items with the status InProgress or the status Pending.
3248 3249 3250 3251 3252 3253 3254 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3248 class ListDeploymentJobsRequest < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
When this parameter is used, ListDeploymentJobs only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListDeploymentJobs request with the returned nextToken value. This value can be between 1 and 200. If this parameter is not used, then ListDeploymentJobs returns up to 200 results and a nextToken value if applicable.
3248 3249 3250 3251 3252 3253 3254 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3248 class ListDeploymentJobsRequest < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s nextToken parameter value is set to a token. To retrieve the next set of results, call ListDeploymentJobs again and assign that token to the request object’s nextToken parameter. If there are no remaining results, the previous response object’s NextToken parameter is set to null.
3248 3249 3250 3251 3252 3253 3254 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3248 class ListDeploymentJobsRequest < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |