Class: Aws::RoboMaker::Types::ListRobotsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::ListRobotsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s
nextTokenparameter value is set to a token. -
#robots ⇒ Array<Types::Robot>
A list of robots that meet the criteria of the request.
Instance Attribute Details
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s nextToken parameter value is set to a token. To retrieve the next set of results, call ListRobots again and assign that token to the request object’s nextToken parameter. If there are no remaining results, the previous response object’s NextToken parameter is set to null.
3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3462 class ListRobotsResponse < Struct.new( :robots, :next_token) SENSITIVE = [] include Aws::Structure end |
#robots ⇒ Array<Types::Robot>
A list of robots that meet the criteria of the request.
3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3462 class ListRobotsResponse < Struct.new( :robots, :next_token) SENSITIVE = [] include Aws::Structure end |