Class: Aws::RoboMaker::Types::ListSimulationJobBatchesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RoboMaker::Types::ListSimulationJobBatchesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-robomaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Optional filters to limit results.
-
#max_results ⇒ Integer
When this parameter is used,
ListSimulationJobBatchesonly returnsmaxResultsresults in a single page along with anextTokenresponse element. -
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s
nextTokenparameter value is set to a token.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Optional filters to limit results.
3561 3562 3563 3564 3565 3566 3567 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3561 class ListSimulationJobBatchesRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
When this parameter is used, ListSimulationJobBatches only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListSimulationJobBatches request with the returned nextToken value.
3561 3562 3563 3564 3565 3566 3567 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3561 class ListSimulationJobBatchesRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous paginated request did not return all of the remaining results, the response object’s nextToken parameter value is set to a token. To retrieve the next set of results, call ListSimulationJobBatches again and assign that token to the request object’s nextToken parameter. If there are no remaining results, the previous response object’s NextToken parameter is set to null.
3561 3562 3563 3564 3565 3566 3567 |
# File 'lib/aws-sdk-robomaker/types.rb', line 3561 class ListSimulationJobBatchesRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |