Class: Aws::RoboMaker::Types::ListSimulationJobBatchesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-robomaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the previous paginated request did not return all of the remaining results, the response object’s nextToken parameter value is set to a token. To retrieve the next set of results, call ListSimulationJobBatches again and assign that token to the request object’s nextToken parameter. If there are no remaining results, the previous response object’s NextToken parameter is set to null.

Returns:

  • (String)


3585
3586
3587
3588
3589
3590
# File 'lib/aws-sdk-robomaker/types.rb', line 3585

class ListSimulationJobBatchesResponse < Struct.new(
  :simulation_job_batch_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#simulation_job_batch_summariesArray<Types::SimulationJobBatchSummary>

A list of simulation job batch summaries.



3585
3586
3587
3588
3589
3590
# File 'lib/aws-sdk-robomaker/types.rb', line 3585

class ListSimulationJobBatchesResponse < Struct.new(
  :simulation_job_batch_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end